summaryrefslogtreecommitdiffstats
path: root/libktorrent/interfaces/filetreeitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'libktorrent/interfaces/filetreeitem.h')
-rw-r--r--libktorrent/interfaces/filetreeitem.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/libktorrent/interfaces/filetreeitem.h b/libktorrent/interfaces/filetreeitem.h
index 6f9f1b1..6d6ed79 100644
--- a/libktorrent/interfaces/filetreeitem.h
+++ b/libktorrent/interfaces/filetreeitem.h
@@ -37,25 +37,25 @@ namespace kt
* @author Joris Guisson
*
* File item part of a tree which shows the files in a multifile torrent.
* This is derived from QCheckListItem, if the user checks or unchecks the box,
* wether or not to download a file will be changed.
*/
- class FileTreeItem : public QCheckListItem
+ class FileTreeItem : public TQCheckListItem
{
protected:
- QString name;
+ TQString name;
TorrentFileInterface & file;
- FileTreeDirItem* parent;
+ FileTreeDirItem* tqparent;
bool manual_change;
public:
/**
* Constructor, set the parent, name and file
* @param item Parent item
* @param name Name of file
* @param file THe TorrentFileInterface
* @return
*/
- FileTreeItem(FileTreeDirItem* item,const QString & name,TorrentFileInterface & file);
+ FileTreeItem(FileTreeDirItem* item,const TQString & name,TorrentFileInterface & file);
virtual ~FileTreeItem();
/// Get a reference to the TorrentFileInterface
@@ -78,7 +78,7 @@ namespace kt
void updatePriorityText();
protected:
- virtual int compare(QListViewItem* i, int col, bool ascending) const;
+ virtual int compare(TQListViewItem* i, int col, bool ascending) const;
/**
* Subclasses should override this if they want to show a confirmation dialog.
@@ -37,25 +37,25 @@ namespace kt
*
* File item part of a tree which shows the files in a multifile torrent.
- * This is derived from QCheckListItem, if the user checks or unchecks the box,
+ * This is derived from TQCheckListItem, if the user checks or unchecks the box,
* wether or not to download a file will be changed.
*/
@@ -37,25 +37,25 @@ namespace kt
public:
/**
- * Constructor, set the parent, name and file
+ * Constructor, set the tqparent, name and file
* @param item Parent item
* @param name Name of file